# WARNING: This package is synced with FC
%global apiversion 0.20
%define major 0

%define libname %mklibname orcus %{apiversion} %{major}
%define develname %mklibname -d orcus

# build conversion tools
%bcond_without convtools

# build python3 bindings
%bcond_without python

Name: liborcus
Version: 0.20.1
Release: %mkrel 1
Summary: Standalone file import filter library for spreadsheet documents
Group: Office/Spreadsheet
License: MPLv2.0
URL: https://gitlab.com/orcus/orcus
Source0: https://gitlab.com/orcus/orcus/-/archive/%{version}/orcus-%{version}.tar.bz2
Patch0: include.patch

BuildRequires: boost-devel
BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: automake
BuildRequires: libtool
%if %{with convtools}
BuildRequires: help2man
BuildRequires: pkgconfig(libixion-0.20)
%endif
BuildRequires: pkgconfig(mdds-3.0)
%if %{with python}
BuildRequires: pkgconfig(python3)
%endif
BuildRequires: pkgconfig(zlib)


%description
%{name} is a standalone file import filter library for spreadsheet
documents. Currently under development are ODS, XLSX and CSV import
filters.

%if %{with convtools}
%package model
Summary: Spreadsheet model for %{name} conversion tools

%description model
The %{name}-model package contains a spreadsheet model used by the
conversion tools.
%endif

%package -n %{libname}
Summary: Standalone file import filter library for spreadsheet documents
Group: Office/Spreadsheet

%description -n %{libname}
%{name} is a standalone file import filter library for spreadsheet
documents. Currently under development are ODS, XLSX and CSV import
filters.

%package -n %{develname}
Summary: Development files for %{name}
Group: Development/C
Requires: %{libname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package tools
Summary: Tools for working with Orcus
Group: Office/Spreadsheet
Requires: %{libname} = %{version}-%{release}

%description tools
Helper tools for %{name} and converters of various file formats to HTML
and text.

%if %{with python}
%package python3
Summary: Python 3 bindings for %{name}

%description python3
Python 3 bindings for %{name}.
%endif

%package doc
Summary: API documentation for %{name}
BuildArch: noarch

%description doc
API documentation for %{name}.

%prep
%autosetup -n orcus-%{version} -p0

%if %{without convtools}
%global condopts %{?condopts} --disable-spreadsheet-model
%endif
%if %{without python}
%global condopts %{?condopts} --disable-python
%endif

%build
NOCONFIGURE=1 ./autogen.sh
%configure --disable-debug --disable-silent-rules --disable-static \
    --disable-werror --with-pic %{?condopts}
%make_build PYTHON_LIBS="-lpython%{python3_version}"

%install
%make_install

%if %{with convtools}
# create and install man pages
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
help2man -N -S '%{name} %{version}' -n 'convert a CSV file' -o orcus-csv.1 %{buildroot}%{_bindir}/orcus-csv
help2man -N -S '%{name} %{version}' -n 'convert a Gnumeric file' -o orcus-gnumeric.1 %{buildroot}%{_bindir}/orcus-gnumeric
help2man -N -S '%{name} %{version}' -n 'convert an ODF spreadsheet' -o orcus-ods.1 %{buildroot}%{_bindir}/orcus-ods
help2man -N -S '%{name} %{version}' -n 'transform an XML file' -o orcus-xls-xml.1 %{buildroot}%{_bindir}/orcus-xls-xml
help2man -N -S '%{name} %{version}' -n 'convert a OpenXML spreadsheet' -o orcus-xlsx.1 %{buildroot}%{_bindir}/orcus-xlsx
help2man -N -S '%{name} %{version}' -n 'convert an XML file' -o orcus-xml.1 %{buildroot}%{_bindir}/orcus-xml
install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -p -m 0644 orcus-*.1 %{buildroot}/%{_mandir}/man1
%endif
 
# build documentation
make doc-doxygen

%check
#TODO, reenable with 0.15.1
exit 0
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
%make_build check

%files -n %{libname}
%doc AUTHORS CHANGELOG
%license LICENSE
%{_libdir}/%{name}*-%{apiversion}.so.%{major}{,.*}


%files -n %{develname}
%{_includedir}/%{name}-%{apiversion}
%{_libdir}/%{name}*-%{apiversion}.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/orcus-css-dump
%{_bindir}/orcus-detect
%{_bindir}/orcus-json
%{_bindir}/orcus-mso-encryption
%{_bindir}/orcus-zip-dump
%{_bindir}/orcus-yaml
%if %{with convtools}
%{_bindir}/orcus-csv
%{_bindir}/orcus-gnumeric
%{_bindir}/orcus-ods
%{_bindir}/orcus-styles-ods
%{_bindir}/orcus-xls-xml
%{_bindir}/orcus-xlsx
%{_bindir}/orcus-xml
%{_mandir}/man1/orcus-csv.1*
%{_mandir}/man1/orcus-gnumeric.1*
%{_mandir}/man1/orcus-ods.1*
%{_mandir}/man1/orcus-xls-xml.1*
%{_mandir}/man1/orcus-xlsx.1*
%{_mandir}/man1/orcus-xml.1*
%endif

%if %{with python}
%files python3
%{python3_sitearch}/_orcus.so
%{python3_sitearch}/_orcus_json.so
%{python3_sitelib}/orcus
%endif

%files doc
%license LICENSE
%doc doc/_doxygen/html



%changelog
* Sun Jul 27 2025 daviddavid <daviddavid> 0.20.1-1.mga10
+ Revision: 2260789
- new version: 0.20.1
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Fri Mar 07 2025 tv <tv> 0.20.0-1.mga10
+ Revision: 2161776
- 0.20.0

* Sat Mar 01 2025 daviddavid <daviddavid> 0.19.2-5.mga10
+ Revision: 2153997
- rebuild for python 3.13

* Sun Feb 09 2025 wally <wally> 0.19.2-4.mga10
+ Revision: 2146242
- rebuild for boost 1.87.0

* Fri Sep 13 2024 wally <wally> 0.19.2-3.mga10
+ Revision: 2095485
- rebuild for boost 1.86.0

* Wed Jun 19 2024 wally <wally> 0.19.2-2.mga10
+ Revision: 2075359
- rebuild for boost 1.85.0

* Sat Mar 30 2024 tv <tv> 0.19.2-1.mga10
+ Revision: 2053315
- 0.19.2

* Fri Jan 12 2024 wally <wally> 0.18.1-4.mga10
+ Revision: 2030558
- rebuild for boost 1.84.0

* Tue Dec 19 2023 papoteur <papoteur> 0.18.1-3.mga10
+ Revision: 2019319
- Mass Rebuild - Python 3.12

* Wed Sep 27 2023 wally <wally> 0.18.1-2.mga10
+ Revision: 1991460
- rebuild for boost 1.83.0

* Mon Sep 11 2023 tv <tv> 0.18.1-1.mga10
+ Revision: 1986327
- 0.18.1

* Sat Dec 24 2022 wally <wally> 0.17.2-5.mga9
+ Revision: 1926494
- rebuild for boost 1.81.0

* Sun Jul 03 2022 wally <wally> 0.17.2-4.mga9
+ Revision: 1867270
- rebuild for boost 1.79.0

* Wed Mar 30 2022 umeabot <umeabot> 0.17.2-3.mga9
+ Revision: 1834372
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 0.17.2-2.mga9
+ Revision: 1787145
- rebuild for python-3.10

* Fri Feb 04 2022 tv <tv> 0.17.2-1.mga9
+ Revision: 1771488
- Update to 0.17.2

* Wed Dec 22 2021 wally <wally> 0.16.1-13.mga9
+ Revision: 1763412
- another rebuild for armv7hl

* Wed Dec 22 2021 wally <wally> 0.16.1-12.mga9
+ Revision: 1763314
- rebuild for missing pkgs in armv7hl

* Sun Dec 19 2021 wally <wally> 0.16.1-11.mga9
+ Revision: 1762603
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 0.16.1-10.mga9
+ Revision: 1744724
- fix RPATH issue with autoreconf
- let post %%install scriptlets remove .la files
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 0.16.1-9.mga9
+ Revision: 1722979
- rebuild for boost 1.76.0

* Wed Apr 21 2021 daviddavid <daviddavid> 0.16.1-8.mga9
+ Revision: 1717704
- rebuild for python 3.9

* Sat Jan 02 2021 wally <wally> 0.16.1-7.mga8
+ Revision: 1668250
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 0.16.1-6.mga8
+ Revision: 1662018
- rebuild for boost 1.74.0
+ tv <tv>
- Make it gcc-11 ready (fix missing headers)

* Tue Sep 29 2020 tv <tv> 0.16.1-5.mga8
+ Revision: 1631154
- 0.16.1

* Fri Sep 25 2020 tv <tv> 0.16.0-5.mga8
+ Revision: 1630000
- replace -DSIZEOF_VOID_P=4 with upstream solution

* Thu Sep 24 2020 tv <tv> 0.16.0-4.mga8
+ Revision: 1629797
- 0.16.0

* Sun May 03 2020 wally <wally> 0.15.3-4.mga8
+ Revision: 1578073
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 0.15.3-3.mga8
+ Revision: 1544803
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 0.15.3-2.mga8
+ Revision: 1483391
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Sun Nov 03 2019 tv <tv> 0.15.3-1.mga8
+ Revision: 1457485
- new release

* Wed Sep 11 2019 wally <wally> 0.15.2-2.mga8
+ Revision: 1439621
- rebuild for python3.8

* Fri Aug 30 2019 tv <tv> 0.15.2-1.mga8
+ Revision: 1435215
- new release

* Mon Aug 26 2019 tv <tv> 0.15.0-1.mga8
+ Revision: 1432313
- new release
- Replace hard-coded /usr/bin with _bindir macro for flatpak build

* Fri Jan 11 2019 daviddavid <daviddavid> 0.14.1-2.mga7
+ Revision: 1354725
- rebuild for new Python 3.7

* Fri Oct 19 2018 wally <wally> 0.14.1-1.mga7
+ Revision: 1322400
- new version 0.14.1
- drop armv5 support
- rebuild for new boost 1.68.0
+ tv <tv>
- fix build with new boost
- do not ignore testsuite result

* Mon Sep 17 2018 wally <wally> 0.14.0-2.mga7
+ Revision: 1259296
- rebuild for aarch64
- drop old/unneeded obsoletes

* Mon Sep 03 2018 tv <tv> 0.14.0-1.mga7
+ Revision: 1256686
- new release

* Sun Sep 02 2018 tv <tv> 0.13.4-2.mga7
+ Revision: 1256151
- fix build with mdds 1.4
- package CHANGELOG

* Sat Mar 03 2018 tv <tv> 0.13.4-1.mga7
+ Revision: 1206379
- new release

* Wed Feb 07 2018 tv <tv> 0.13.2-1.mga7
+ Revision: 1199554
- ignore testsuite result as previous version is broken too now
- reeanble doc subpkg
- new release

* Mon Dec 25 2017 wally <wally> 0.13.1-2.mga7
+ Revision: 1184681
- rebuild for new boost

* Wed Nov 22 2017 tv <tv> 0.13.1-1.mga7
+ Revision: 1178563
- drop no more needed patch
- new release

* Sun Nov 19 2017 tv <tv> 0.12.1-5.mga7
+ Revision: 1177735
- coverity: fix comparison

* Sat Sep 16 2017 tv <tv> 0.12.1-4.mga7
+ Revision: 1154537
- rebuild with latest boost

* Sat Aug 05 2017 pterjan <pterjan> 0.12.1-3.mga7
+ Revision: 1135256
- Rebuild for python 3.6

* Mon Jan 09 2017 luigiwalser <luigiwalser> 0.12.1-2.mga6
+ Revision: 1080784
- disable broken apidoc generation

* Fri Sep 30 2016 tv <tv> 0.12.1-1.mga6
+ Revision: 1057855
- new release

* Sat Sep 24 2016 tv <tv> 0.11.2-6.mga6
+ Revision: 1055651
- fix file list on armv5tl... :-(

* Fri Sep 23 2016 tv <tv> 0.11.2-5.mga6
+ Revision: 1055594
- try even harder to fix building on armv5tl

* Fri Sep 23 2016 tv <tv> 0.11.2-4.mga6
+ Revision: 1055583
- fix inverted test for armv5tl
- try harder to disable convtools on armv5tl

* Fri Sep 23 2016 tv <tv> 0.11.2-2.mga6
+ Revision: 1055573
- disable convtools on armv5tl due to missing libixion

* Mon Sep 19 2016 tv <tv> 0.11.2-1.mga6
+ Revision: 1054476
- new release
- build with new mdds & new ixion

* Mon May 09 2016 luigiwalser <luigiwalser> 0.11.1-1.mga6
+ Revision: 1011485
- 0.11.1

* Sat Mar 19 2016 luigiwalser <luigiwalser> 0.11.0-2.mga6
+ Revision: 993030
- remove invalid deps from subpackages

* Sat Mar 12 2016 tv <tv> 0.11.0-1.mga6
+ Revision: 989382
- adjust file list
- patch 100: fix underlinking
- add model subpkg
- new release
- add doc & python3 subpkgs

* Wed Mar 02 2016 tv <tv> 0.9.2-3.mga6
+ Revision: 983692
- reenable patch 1
- patch 2: fix build
- disable patch 1
- switch to new mdds and libixion

* Fri Dec 25 2015 tv <tv> 0.9.2-2.mga6
+ Revision: 914724
- rebuild for new boost 1.60

* Fri Oct 30 2015 tv <tv> 0.9.2-1.mga6
+ Revision: 896546
- new release

* Fri Sep 25 2015 tv <tv> 0.7.1-4.mga6
+ Revision: 883527
- rebuild for new boost

* Wed Aug 26 2015 tv <tv> 0.7.1-3.mga6
+ Revision: 869858
- rebuild with gcc5

* Fri Jul 31 2015 neoclust <neoclust> 0.7.1-2.mga6
+ Revision: 859844
- Rebuild against new boost

* Sun Jun 21 2015 tv <tv> 0.7.1-1.mga6
+ Revision: 837884
- new URL
- new release

* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-4.mga5
+ Revision: 743631
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-3.mga5
+ Revision: 681690
- Mageia 5 Mass Rebuild

* Thu Jul 31 2014 tv <tv> 0.7.0-2.mga5
+ Revision: 658706
- drop old patches
- rebuild for having a fixed package
- new release

* Sat Feb 08 2014 barjac <barjac> 0.5.1-10.mga5
+ Revision: 586669
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 0.5.1-9.mga4
+ Revision: 529281
- Mageia 4 Mass Rebuild

* Mon Jul 08 2013 fwang <fwang> 0.5.1-8.mga4
+ Revision: 451227
- rebuild for new boost

* Sat Jun 08 2013 tv <tv> 0.5.1-7.mga4
+ Revision: 440697
- fix obsoletes

* Sat Jun 08 2013 tv <tv> 0.5.1-6.mga4
+ Revision: 440661
- more obsolete for temporary liborcus0.4

* Sat Jun 08 2013 tv <tv> 0.5.1-4.mga4
+ Revision: 440632
- obsolete temporary liborcus0.4 package

* Sat May 25 2013 tv <tv> 0.5.1-2.mga4
+ Revision: 426989
- adjust file list
- bump library api
- further fix linking
- further fix linking
- patch 1: fix linking with boost
- new release
- new release

* Thu Apr 11 2013 ennael <ennael> 0.3.0-5.mga3
+ Revision: 409490
- rebuild for boost 1.53

* Sat Jan 12 2013 umeabot <umeabot> 0.3.0-4.mga3
+ Revision: 357937
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 0.3.0-3.mga3
+ Revision: 333080
- fix obsoletes

* Thu Dec 20 2012 fwang <fwang> 0.3.0-2.mga3
+ Revision: 333001
- fix missing includes
- use configure2_5x
- rebuild for new boost

* Mon Dec 17 2012 tv <tv> 0.3.0-1.mga3
+ Revision: 331976
- fix new release
- fix new release

* Mon Dec 17 2012 tv <tv> 0.1.0-1.mga3
+ Revision: 331938
- fix group
- fix group
- imported package liborcus


* Mon Dec 17 2012 Thierry Vignaud <tv@mageia.org> 0.1.0-1.mga3
- import from FC
